#  Copyright (c) 2019 Markus Ressel
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.

Client_Id = "Client-ID"
Drop_Event_Queue = "Drop-Event-Queue"
X_Auth_Token = "X-Auth-Token"

CONFIG_NODE_ROOT = "barcode_server"

CONFIG_NODE_SERVER = "server"
CONFIG_NODE_HTTP = "http"
CONFIG_NODE_MQTT = "mqtt"

CONFIG_NODE_STATS = "stats"
CONFIG_NODE_PORT = "port"

DEFAULT_SERVER_HOST = "127.0.0.1"
DEFAULT_SERVER_PORT = 9654

ENDPOINT_DEVICES = "devices"
